@@ -26,7 +26,6 @@
 #include <KScoreDialog>
 #include <KShortcutsDialog>
 #include <KToggleAction>
-#include <kxmlgui_version.h>
 
 #define USE_UNSTABLE_LIBKDEGAMESPRIVATE_API
 #include <libkdegamesprivate/kgamethemeselector.h>
@@ -64,25 +63,25 @@ KTron::KTron(QWidget *parent) : KXmlGuiWindow(parent, Qt::WindowFlags()) {
 	// We must disable the actions, otherwise we don't get the keyPressEvent's
 
 	m_player0Up = actionCollection()->addAction( QStringLiteral( "Pl1Up" ));
-	m_player0Up->setText(i18n("Right Player / KSnake: Up"));
+	m_player0Up->setText(i18n("Right Player / KSnake mode: Up"));
 	actionCollection()->setDefaultShortcut(m_player0Up,Qt::Key_Up);
 	connect(m_player0Up, &QAction::triggered, this, &KTron::triggerKey0Up);
 	addAction(m_player0Up);
 
 	m_player0Down = actionCollection()->addAction( QStringLiteral( "Pl1Down" ));
-	m_player0Down->setText(i18n("Right Player / KSnake: Down"));
+	m_player0Down->setText(i18n("Right Player / KSnake mode: Down"));
 	actionCollection()->setDefaultShortcut(m_player0Down,Qt::Key_Down);
 	connect(m_player0Down, &QAction::triggered, this, &KTron::triggerKey0Down);
 	addAction(m_player0Down);
 
 	m_player0Right = actionCollection()->addAction( QStringLiteral( "Pl1Right" ));
-	m_player0Right->setText(i18n("Right Player / KSnake: Right"));
+	m_player0Right->setText(i18n("Right Player / KSnake mode: Right"));
 	actionCollection()->setDefaultShortcut(m_player0Right,Qt::Key_Right);
 	connect(m_player0Right, &QAction::triggered, this, &KTron::triggerKey0Right);
 	addAction(m_player0Right);
 
 	m_player0Left = actionCollection()->addAction( QStringLiteral( "Pl1Left" ));
-	m_player0Left->setText(i18n("Right Player / KSnake: Left"));
+	m_player0Left->setText(i18n("Right Player / KSnake mode: Left"));
 	actionCollection()->setDefaultShortcut(m_player0Left,Qt::Key_Left);
 	connect(m_player0Left, &QAction::triggered, this, &KTron::triggerKey0Left);
 	addAction(m_player0Left);
@@ -253,8 +252,8 @@ void KTron::showSettings(){
 		m_generalConfigDialog->namePlayer2Label->setText(i18n("Opponent:"));
 	}
 	else {
-		m_generalConfigDialog->namePlayer1Label->setText(i18n("Right Player:"));
-		m_generalConfigDialog->namePlayer2Label->setText(i18n("Left Player:"));
+		m_generalConfigDialog->namePlayer1Label->setText(i18n("Right player:"));
+		m_generalConfigDialog->namePlayer2Label->setText(i18n("Left player:"));
 	}
 
 	KConfigDialog *dialog = new KConfigDialog(this, QStringLiteral( "settings" ), Settings::self());
@@ -289,11 +288,7 @@ void KTron::closeEvent(QCloseEvent *event)
 
 void KTron::optionsConfigureKeys()
 {
-#if KXMLGUI_VERSION >= QT_VERSION_CHECK(5,84,0)
     KShortcutsDialog::showDialog(actionCollection(), KShortcutsEditor::LetterShortcutsAllowed, this);
-#else
-    KShortcutsDialog::configure(actionCollection());
-#endif
 }
 
 // Key events
